@@ -59,9 +59,21 @@ INTERNALERROR_CALLEEERROR = 'InternalError.CalleeError'
 # An internal request error occurred.
 INTERNALERROR_REQUESTERROR = 'InternalError.RequestError'
 
+# The image cannot be found.
+INVALIDIMAGEID_NOTFOUND = 'InvalidImageId.NotFound'
+
+# Invalid launch configuration.
+INVALIDLAUNCHCONFIGURATION = 'InvalidLaunchConfiguration'
+
+# The launch configuration ID is invalid.
+INVALIDLAUNCHCONFIGURATIONID = 'InvalidLaunchConfigurationId'
+
 # Invalid parameter.
 INVALIDPARAMETER = 'InvalidParameter'
 
+# Invalid Action request.
+INVALIDPARAMETER_ACTIONNOTFOUND = 'InvalidParameter.ActionNotFound'
+
 # Multiple parameters specified conflict and cannot co-exist.
 INVALIDPARAMETER_CONFLICT = 'InvalidParameter.Conflict'
 
@@ -155,6 +167,9 @@ INVALIDPARAMETERVALUE_INVALIDCLBREGION = 'InvalidParameterValue.InvalidClbRegion
 # Invalid filter condition.
 INVALIDPARAMETERVALUE_INVALIDFILTER = 'InvalidParameterValue.InvalidFilter'
 
+# 
+INVALIDPARAMETERVALUE_INVALIDHPCCLUSTERID = 'InvalidParameterValue.InvalidHpcClusterId'
+
 # Invalid image ID.
 INVALIDPARAMETERVALUE_INVALIDIMAGEID = 'InvalidParameterValue.InvalidImageId'
 
@@ -164,6 +179,9 @@ INVALIDPARAMETERVALUE_INVALIDINSTANCEID = 'InvalidParameterValue.InvalidInstance
 # Invalid instance type.
 INVALIDPARAMETERVALUE_INVALIDINSTANCETYPE = 'InvalidParameterValue.InvalidInstanceType'
 
+# Invalid launch configuration
+INVALIDPARAMETERVALUE_INVALIDLAUNCHCONFIGURATION = 'InvalidParameterValue.InvalidLaunchConfiguration'
+
 # Invalid launch configuration ID.
 INVALIDPARAMETERVALUE_INVALIDLAUNCHCONFIGURATIONID = 'InvalidParameterValue.InvalidLaunchConfigurationId'
 
@@ -179,6 +197,9 @@ INVALIDPARAMETERVALUE_INVALIDSCHEDULEDACTIONID = 'InvalidParameterValue.InvalidS
 # The scheduled task name contains invalid characters.
 INVALIDPARAMETERVALUE_INVALIDSCHEDULEDACTIONNAMEINCLUDEILLEGALCHAR = 'InvalidParameterValue.InvalidScheduledActionNameIncludeIllegalChar'
 
+# Invalid snapshot ID.
+INVALIDPARAMETERVALUE_INVALIDSNAPSHOTID = 'InvalidParameterValue.InvalidSnapshotId'
+
 # Invalid subnet ID.
 INVALIDPARAMETERVALUE_INVALIDSUBNETID = 'InvalidParameterValue.InvalidSubnetId'
 
@@ -272,6 +293,9 @@ LIMITEXCEEDED_DESIREDCAPACITYLIMITEXCEEDED = 'LimitExceeded.DesiredCapacityLimit
 # Too many values for the specified filter
 LIMITEXCEEDED_FILTERVALUESTOOLONG = 'LimitExceeded.FilterValuesTooLong'
 
+# You are short of the launch configuration quota.
+LIMITEXCEEDED_LAUNCHCONFIGURATIONQUOTANOTENOUGH = 'LimitExceeded.LaunchConfigurationQuotaNotEnough'
+
 # The maximum number of instances exceeds the limit.
 LIMITEXCEEDED_MAXSIZELIMITEXCEEDED = 'LimitExceeded.MaxSizeLimitExceeded'
 
@@ -290,6 +314,9 @@ MISSINGPARAMETER = 'MissingParameter'
 # A parameter is missing in a specific scenario.
 MISSINGPARAMETER_INSCENARIO = 'MissingParameter.InScenario'
 
+# The `InstanceMarketOptions` parameter of the spot instance is missing.
+MISSINGPARAMETER_INSTANCEMARKETOPTIONS = 'MissingParameter.InstanceMarketOptions'
+
 # The auto scaling group is performing a scaling activity.
 RESOURCEINUSE_ACTIVITYINPROGRESS = 'ResourceInUse.ActivityInProgress'
 
@@ -377,6 +404,9 @@ RESOURCEUNAVAILABLE_CMQTOPICHASNOSUBSCRIBER = 'ResourceUnavailable.CmqTopicHasNo
 # The instance and the auto scaling group are in different VPCs.
 RESOURCEUNAVAILABLE_CVMVPCINCONSISTENT = 'ResourceUnavailable.CvmVpcInconsistent'
 
+# Unable to add the instance to the scaling group.
+RESOURCEUNAVAILABLE_INSTANCECANNOTATTACH = 'ResourceUnavailable.InstanceCannotAttach'
+
 # The specified instance is active.
 RESOURCEUNAVAILABLE_INSTANCEINOPERATION = 'ResourceUnavailable.InstanceInOperation'
 
@@ -415,3 +445,6 @@ RESOURCEUNAVAILABLE_TDMQCMQTOPICHASNOSUBSCRIBER = 'ResourceUnavailable.TDMQCMQTo
 
 # The specified availability zone is unavailable.
 RESOURCEUNAVAILABLE_ZONEUNAVAILABLE = 'ResourceUnavailable.ZoneUnavailable'
+
+# Unsupported operation.
+UNSUPPORTEDOPERATION = 'UnsupportedOperation'
